﻿using System;
using Android.App;
using Android.Content;
using Android.Widget;
using Android.OS;
using com.multisoft.drivers.fiscalcore;
using Com.Multisoft.Drivers.Fiscalcore;
// ReSharper disable InconsistentNaming

namespace ConnectionExample
{
    [Activity(Label = "ConnectionExample", MainLauncher = true, Icon = "@mipmap/icon")]
    public class MainActivity : Activity
    {
        private Button _button;
        private TextView _textView;
        private FiscalCoreServiceConnection _connection;

        private const string REMOTE_SERVICE_ACTION_NAME = "com.multisoft.drivers.fiscalcore.IFiscalCore";
        private const string REMOTE_SERVICE_PACKAGE_NAME = "com.multisoft.drivers.fiscalcore";
        private const string REMOTE_SERVICE_COMPONENT_NAME = "com.multisoft.fiscalcore";

        protected override void OnCreate(Bundle savedInstanceState)
        {
            base.OnCreate(savedInstanceState);
            
            SetContentView(Resource.Layout.Main);

            _button = FindViewById<Button>(Resource.Id.myButton);
            _button.Click += OnClick;

            var serviceIntent = new Intent();
            serviceIntent.SetPackage(REMOTE_SERVICE_PACKAGE_NAME);
            ComponentName cn = new ComponentName(REMOTE_SERVICE_PACKAGE_NAME, REMOTE_SERVICE_COMPONENT_NAME);
            serviceIntent.SetComponent(cn);
            serviceIntent.SetAction(REMOTE_SERVICE_ACTION_NAME);

            _connection = new FiscalCoreServiceConnection();

            var bound = BindService(serviceIntent, _connection, Bind.AutoCreate);
            var boundTextResult = Resources.GetString(Resource.String.esteablished);
            if (!bound)
                boundTextResult = Resources.GetString(Resource.String.not_) + boundTextResult;

            _textView = FindViewById<TextView>(Resource.Id.textViewResult);
            _textView.Text = Resources.GetString(Resource.String.connection2service_) + boundTextResult;
        }

        protected override void OnDestroy()
        {
            if(null != _button)
                _button.Click -= OnClick;
            base.OnDestroy();
        }

        private void OnClick(object sender, EventArgs e)
        {
            TestPrintUnfiscal(_connection.Core);
        }

        private void TestPrintUnfiscal(IFiscalCore core)
        {
            try
            {
                if (null == core)
                    throw new ArgumentNullException(Resources.GetString(Resource.String.serviceNotReady));

                var callback = new ExceptionCallback();
                core.OpenRec((int)RecType.Unfiscal, callback);
                callback.Complete();

                var testText = FindViewById<EditText>(Resource.Id.editText).Text;
                core.PrintLine((int)Align.Center, testText, callback);
                callback.Complete();

                core.CloseRec(callback);
                callback.Complete();
            }
            catch (Exception e)
            {
                Toast.MakeText(this, e.Message, ToastLength.Short);
            }
        }
    }
}

