﻿using System;
using System.ComponentModel;
// ReSharper disable InconsistentNaming

//[Description()]

namespace com.multisoft.drivers.fiscalcore
{
    /// <summary>
    /// Код ошибки. Является аргументом errCode функции <see href="http://doc.multisoft.ru/doc/MSPOS/IExceptionCallback.aidl"><see href="http://doc.multisoft.ru/doc/MSPOS/IExceptionCallback.aidl">IExceptionCallback.HandleException</see></see>
    /// </summary>
    public enum ErrCode
    {
        /// <summary>
        /// 0 -стандартное исключение. Дополнительная информация в StackTrace
        /// </summary>
        [Description("Исключение")]
        Generic = 0,

        /// <summary>
        /// 1 -Некорректное значение параметра
        /// при передаче даты/времени и денежных сумм
        /// </summary>
        [Description("Неправильный аргумент")]
        WrongArgument = 1,

        /// <summary>
        /// 2  -Параметр выходит за заданный диапазон, например, при использовании перечислений
        /// </summary>
        [Description("Выход за границы диапазона")]
        OutOfRange = 2,

        /// <summary>
        /// 3 -Операция невыполнима при данном статусе. см. ExtStatusErr
        /// например, если пытаемся добавить товары после итога
        /// </summary>
        [Description("Неверный статус")]
        WrongStatus = 3,

        /// <summary>
        /// 4 -Ошибка оборудования: проверьте FNState и WarningFlags см. ExtHardwareErr
        /// </summary>
        [Description("Ошибка оборудования")]
        Hardware = 4,

        /// <summary>
        /// 5 -Ошибка печатающего устройства. См. ExtPrinterErr
        /// </summary>
        [Description("Ошибка принтера")]
        Printer = 5
    }

    /// <summary>
    /// расширенный код ошибки статуса.  Является аргументом extErrCode функции <see href="http://doc.multisoft.ru/doc/MSPOS/IExceptionCallback.aidl">IExceptionCallback.HandleException</see>
    /// </summary>
    public enum ExtStatusErr
    {
        /// <summary>
        /// 0 -Сервис не готов. Если не готов более 12 секунд, перезагрузите устройство
        /// </summary>
        [Description("Сервис не инициализирован либо не готов к работе")]
        ServiceNotReady = 0,

        /// <summary>
        /// 1 -Смена уже открыта
        /// </summary>
        [Description("Смена уже открыта")]
        DayOpened = 1,

        /// <summary>
        /// 2 -Смена уже закрыта
        /// </summary>
        [Description("Смена уже закрыта")]
        DayClosed = 2,

        /// <summary>
        /// 3 -Смена открыта более 24 часов
        /// </summary>
        [Description("Смена открыта более 24 часов")]
        DayOpened24h = 3,

        /// <summary>
        /// 4 -Состояние смены в ККТ и накопителе различно.
        /// </summary>
        [Description("Состояние смены в ККТ и накопителе различно")]
        DayStateDiffers = 4,

        /// <summary>
        /// 5 -Неверное состояние чека.
        /// </summary>
        [Description("Неверное состояние чека.")]
        WrongRecState = 5,

        /// <summary>
        /// 6 -Для выполнения данной операции необходимо закрыть чек
        /// </summary>
        [Description("Необходимо закрыть чек")]
        NeedRecClose = 6,

        /// <summary>
        /// 7 -Недостаточно наличных
        /// </summary>
        [Description("Недостаточно наличных")]
        NotEnoughCash = 7,

        /// <summary>
        /// 8 -Не передан один из обязательных реквизитов
        /// </summary>
        [Description("Необходимо передать реквизит")]
        MissingProps = 8,

        /// <summary>
        /// 9 -Неправильный тип документа
        /// </summary>
        [Description("Неправильный тип документа")]
        WrongRecType = 9,

        /// <summary>
        /// 10 -Общая ошибка статуса
        /// </summary>
        [Description("Общая ошибка статуса")]
        Common = 10,

        /// <summary>
        /// 11 -Cумма по чеку не совпадает с суммой по оплатам
        /// </summary>
        [Description("Сумма по чеку не совпадает с суммой по оплатам")]
        TotalDiffers = 11,

        /// <summary>
        /// 12 - Неверная разница во времени между 2 операцяими
        /// </summary>
        [Description("Неверная разница во времени между 2 операцяими")]
        BadTimeDifference = 12,

        /// <summary>
        /// 13 - Запрещена работа с маркированными товарами.
        /// При активации ФН 1.2 не был установлен признак работы с маркированными товарами.
        /// </summary>
        [Description("Запрещена работа с маркированными товарами")]
        MarkingCheckRestricted = 13,
        /// <summary>
        /// 14 - Неверная последовательность команд группы Bxh.
        /// Нарушена правильная последовательность подачи команд для обработки маркированных товаров.
        /// </summary>
        [Description("Неверная последовательность команд группы Bxh")]
        MarkingCheckFlowViolated = 14,
        /// <summary>
        /// 15 - Работа с маркированными товарами временно заблокирована.
        /// Область временного хранения уведомлений о реализации маркированного товара полностью заполнена. Невозможно формирование новых уведомлений.
        /// </summary>
        [Description("Работа с маркированными товарами временно заблокирована")]
        NotificationStorageFull = 15,
        /// <summary>
        /// 16 - Переполнена таблица проверки кодов маркировки.
        /// ФН допускает включение чек не более 128 КМ. ФН сохраняет результаты проверки КМ в таблице проверки.
        /// </summary>
        [Description("Переполнена таблица проверки кодов маркировки")]
        MarkingStorageFull = 16,
        /// <summary>
        /// 17 - В реквизите 2007 содержится КМ, который ранее не проверялся в ФН.
        /// </summary>
        [Description("В реквизите 2007 содержится КМ, который ранее не проверялся в ФН")]
        UnverifiedMarkingCode = 17,
        /// <summary>
        /// 18 - Превышен период 90 дней со времени последнего обновления ключей проверки.
        /// Произвести процедуру обновления ключей проверки КМ.
        /// </summary>
        [Description("Превышен период 90 дней со времени последнего обновления ключей проверки")]
        KeyUpdateQueryOver90Day = 18,
        /// <summary>
        /// 19 - Отрицательный ответ сервиса обновления ключей проверки КМ.
        /// Сервис обновления ключей проверки КМ уведомил об отказе в выполнении запроса.
        /// </summary>
        [Description("Отрицательный ответ сервиса обновления ключей проверки КМ")]
        KeysUpdateQueryError = 19,
        /// <summary>
        /// 20 - Неизвестный ответ сервиса обновления ключей проверки кодов проверки.
        /// </summary>
        [Description("Неизвестный ответ сервиса обновления ключей проверки кодов проверки")]
        KeysUpdateQueryUnknownResponse = 20,
        /// <summary>
        /// 21 - Требуется повтор процедуры обновления ключей проверки КМ.
        /// </summary>
        [Description("Требуется повтор процедуры обновления ключей проверки КМ")]
        KeysUpdateQueryRepeatRequired = 21
    }

    /// <summary>
    /// расширенный код ошибки оборудования.  Является аргументом extErrCode функции <see href="http://doc.multisoft.ru/doc/MSPOS/IExceptionCallback.aidl">IExceptionCallback.HandleException</see>. Для дополнительной информации см. StackTrace
    /// </summary>
    public enum ExtHardwareErr
    {
        /// <summary>
        /// 0 -Ошибка инициализации. Модуль не был инициализирован.
        /// </summary>
        [Description("Ошибка инициализации")]
        Initialization = 0,

        /// <summary>
        /// 1 -Запрашиваемый модуль не доступен.
        /// </summary>
        [Description("Ошибка доступа")]
        Null = 1,

        /// <summary>
        /// 2 -Ошибка подключения.
        /// </summary>
        [Description("Ошибка подключения")]
        Connection = 2,

        /// <summary>
        /// 3 -Таймаут на выполнение команды. Запрос выполнен успешно, но нет ответа.
        /// </summary>
        [Description("Таймаут")]
        Timeout = 3,

        /// <summary>
        /// 4 -Запрос отклонён
        /// </summary>
        [Description("Запрос отклонён")]
        Nack = 4,

        /// <summary>
        /// 5 -Фатальная ошибка. Обратитесь к производителю.
        /// </summary>
        [Description("Фатальная ошибка")]
        Fatal = 5

    }
    /// <summary>
    /// расширенный код ошибки принтера.  Является аргументом extErrCode функции <see href="http://doc.multisoft.ru/doc/MSPOS/IExceptionCallback.aidl">IExceptionCallback.HandleException</see>
    /// </summary>
    public enum ExtPrinterErr
    {
        /// <summary>
        /// 0 -Бумага скоро закончится. (Поддерживаемые модели: K1)
        /// </summary>
        [Description("Бумага скоро закончится")]
        PaperNearEnd = 0,

        /// <summary>
        /// 1 -Бумага закончилась. (Поддерживаемые модели: K1)
        /// </summary>
        [Description("Бумага закончилась")]
        PaperEnd = 1,

        /// <summary>
        /// 2 -Ошибка при печати. (Поддерживаемые модели: V1, P1, P2, T1, K1)
        /// </summary>
        [Description("Ошибка при печати")]
        ErrorPrinting = 2,

        /// <summary>
        /// 3 -Принтер недоступен. (Поддерживаемые модели: K1)
        /// </summary>
        [Description("Принтер недоступен")]
        Offline = 3,

        /// <summary>
        /// 4 -Открыта крышка. (Поддерживаемые модели: K1)
        /// </summary>
        [Description("Открыта крышка")]
        CoverOpen = 4,

        /// <summary>
        /// 5 -Перегрев. (Поддерживаемые модели: K1)
        /// </summary>
        [Description("Перегрев")]
        Overheat = 5
    }

    /// <summary>
    /// Фазы жизни ФН
    /// </summary>
    public enum FNState
    {
        /// <summary>
        /// 0x00 -Настройка
        /// </summary>
        [Description("Настройка")]
        Configuration = 0x00,

        /// <summary>
        /// 0x01 -Готов к фискализации
        /// </summary>
        [Description("Готов к регистрации")]
        ReadyToFiscalization = 0x01,

        /// <summary>
        /// 0x03 -Фискальный режим
        /// </summary>
        [Description("Фискальный режим")]
        FiscalMode = 0x03,

        /// <summary>
        /// 0x07 -Фискальный режим закрыт, идёт передача ОФД
        /// </summary>
        [Description(" Фискальный режим закрыт, идёт передача ОФД")]
        FiscalClosed = 0x07,

        /// <summary>
        /// 0x0F -Чтение данных из архива ФН
        /// </summary>
        [Description("Чтение данных из архива ФН")]
        FNArchiveRead = 0x0F
    }

    /// <summary>
    /// Флаги педупреждений (битовые)
    /// </summary>
    [Flags]
    public enum WarningFlag
    {
        /// <summary>
        /// 0x00 -Никаких предупреждений
        /// </summary>
        [Description("Никаких предупреждений")]
        OK = 0x00,

        /// <summary>
        /// 0x01 -Срочная замена КС (до окончания срока действия 3 дня)
        /// </summary>
        [Description("Срочная замена КС (до окончания срока действия 3 дня)")]
        UrgentCSReplace = 0x01,

        /// <summary>
        /// 0x02 -Исчерпание ресурса КС (до окончания срока действия 30 дней)
        /// </summary>
        [Description("Исчерпание ресурса КС (до окончания срока действия 30 дней)")]
        CSDepletion = 0x02,

        /// <summary>
        /// 0x04 -Переполнение памяти ФН (архив ФН заполнен на 90%)
        /// </summary>
        [Description("Переполнение памяти ФН (архив ФН заполнен на 90%)")]
        FNMemoryOverflow = 0x04,

        /// <summary>
        /// 0x08 -Превышено время ожидания ответа ОФД
        /// </summary>
        [Description("Превышено время ожидания ответа ОФД")]
        OFDTimeout = 0x08,

        /// <summary>
        /// 0x80 -Критическая ошибка ФН
        /// </summary>
        [Description("Критическая ошибка ФН")]
        FatalError = 0x80,

        /// <summary>
        /// Отказ по данным форматно-логического контроля (признак передается в Подтверждении от ОФД)
        /// </summary>
        [Description("Отказ по данным ФЛК")]
        FlcFailed = 0x10,

        /// <summary>
        /// Требуется настройка ККТ (признак передается в Подтверждении от ОФД)
        /// </summary>
        [Description("Требуется настройка ККТ")]
        ConfigurationNeeded = 0x20,

        /// <summary>
        /// ОФД аннулирован (признак передается в Подтверждении от ОФД)
        /// </summary>
        [Description("ОФД аннулирован")]
        OfdDisabled = 0x40
    }

    /// <summary>
    /// Текущий документ (ответ для запроса статуса ФН)
    /// </summary>
    public enum CurrentDoc
    {
        /// <summary>
        /// 0x00 -Нет открытого документа
        /// </summary>
        [Description("Нет открытого документа")]
        NoDoc = 0x00,

        /// <summary>
        /// 0x01 -Отчёт о фискализации
        /// </summary>
        [Description("Отчёт о фискализации")]
        FiscalizationReport = 0x01,

        /// <summary>
        /// 0x02 -Отчёт об открытии смены
        /// </summary>
        [Description("Отчёт об открытии смены")]
        DayOpenReport = 0x02,

        /// <summary>
        /// 0x04 -Кассовый чек
        /// </summary>
        [Description("Кассовый чек")]
        CashReceipt = 0x04,

        /// <summary>
        /// 0x08 -Отчёт о закрытии смены
        /// </summary>
        [Description("Отчёт о закрытии смены")]
        DayCloseReport = 0x08,

        /// <summary>
        /// 0x10 -Отчёт о закрытии фискального режима
        /// </summary>
        [Description("Отчёт о закрытии фискального режима")]
        FiscalCloseReport = 0x10,

        /// <summary>
        /// 0x11 -Бланк строгой отчётности
        /// </summary>
        [Description("Бланк строгой отчётности")]
        BSO = 0x11,

        /// <summary>
        /// 0x12 -Отчет об изменении параметров регистрации ККТ в связи с заменой ФН
        /// </summary>
        [Description("Отчет об изменении параметров регистрации ККТ в связи с заменой ФН")]
        ReplacedFnRegistrationReport = 0x12,

        /// <summary>
        /// 0x13 -Отчет об изменении параметров регистрации ККТ
        /// </summary>
        [Description(" Отчет об изменении параметров регистрации ККТ")]
        ChangedRegistrationParamsReport = 0x13,

        /// <summary>
        /// 0x14 -Кассовый чек коррекции
        /// </summary>
        [Description("Кассовый чек коррекции")]
        CorrectionCashReceipt = 0x14,

        /// <summary>
        /// 0x15 -БСО коррекции
        /// </summary>
        [Description("БСО коррекции")]
        CorrectionBSO = 0x15,

        /// <summary>
        /// 0x17 -Отчет о текущем состоянии расчетов
        /// </summary>
        [Description("Отчет о текущем состоянии расчетов")]
        CurrentCalculationStateReport = 0x17
    }

    /// <summary>
    /// Типы оплат
    /// </summary>
    public enum PayType
    {
        /// <summary>
        /// 0 -наличными
        /// </summary>
        [Description("НАЛИЧНЫМИ")]
        Cash = 0,

        /// <summary>
        /// 1 -электронными
        /// </summary>
        [Description("БЕЗНАЛИЧНЫМИ")]
        Card = 1,

        /// <summary>
        ///  -в кредит
        /// </summary>
        [Description("ПОСЛЕДУЮЩАЯ ОПЛАТА(КРЕДИТ)")]
        Bank = 2,

        /// <summary>
        /// 3 -аванс
        /// </summary>
        [Description("ПРЕДВАРИТЕЛЬНАЯ ОПЛАТА(АВАНС)")]
        Voucher = 3,

        /// <summary>
        /// 4 -обмен
        /// </summary>
        [Description("ИНАЯ ФОРМА ОПЛАТЫ")]
        Tare = 4
    }

    /// <summary>
    /// Отметка о получении данных документа накопителем (ФН)
    /// </summary>
    public enum DocData
    {
        /// <summary>
        /// 0x00 -Данные документа не получены ФН
        /// </summary>
        [Description("Данные документа не получены ФН")]
        NoData = 0x00,

        /// <summary>
        /// 0x01 -Данные документа получены ФН
        /// </summary>
        [Description("Данные документа получены ФН")]
        DataAcquired = 0x01
    }


    /// <summary>
    /// Тип документа в запросе документа по номеру
    /// </summary>
    public enum DocType : byte
    {
        /// <summary>
        /// 0x00 -Неверный тип документа
        /// </summary>
        [Description("Тип документа не определен")]
        Null = 0x00,
        /// <summary>
        /// 0x01 -Итоги фискализации / Отчёт о регистрации
        /// </summary>
        [Description("Отчет о регистрации")]
        FiscalSummary = 0x01,
        /// <summary>
        /// 0x02 -Отчёт об открытии смены
        /// </summary>
        [Description("Отчет об открытии смены")]
        DayOpen = 0x02,
        /// <summary>
        /// 0x03 -Кассовый чек
        /// </summary>
        [Description("Кассовый чек")]
        CashReceipt = 0x03,
        /// <summary>
        /// 0x04 -Бланк строгой отчётности (БСО)
        /// </summary>
        [Description("Бланк строгой отчетности (БСО)")]
        BSO = 0x04,
        /// <summary>
        /// 0x05 -Отчёт о закрытии смены
        /// </summary>
        [Description("Отчёт о закрытии смены")]
        DayClose = 0x05,
        /// <summary>
        /// 0x06 -Отчёт о закрытии фискального режима
        /// </summary>
        [Description("Отчёт о закрытии фискального режима")]
        FiscalClose = 0x06,
        /// <summary>
        /// 0x07 -Подтверждение оператора
        /// </summary>
        [Description("Подтверждение оператора")]
        OFDConfirm = 0x07,
        /// <summary>
        /// 0x0B -Отчёт об изменении параметров регистрации
        /// </summary>
        [Description("Отчёт об изменении параметров регистрации")]
        RegistrationCorrection = 0x0B,
        /// <summary>
        /// 0x15 -Отчёт о текущем состоянии расчётов
        /// </summary>
        [Description("Отчёт о текущем состоянии расчётов")]
        CalculationsReport = 0x15,

        /// <summary>
        /// 0x1F -Чек коррекции (нет в доке на ФН, но есть в доке на ФД)
        /// </summary>
        [Description("Чек коррекции")]
        CorrectionReceipt = 0x1F,
        /// <summary>
        /// 0x29 -Бланк строгой отчётности коррекции (нет в доке на ФН, но есть в доке на ФД)
        /// </summary>
        [Description("Бланк строгой отчётности коррекции")]
        CorrectionBSO = 0x29
    }

    /// <summary>
    /// Тип ПО ФН
    /// </summary>
    public enum FirmwareTypes
    {
        /// <summary>
        /// 0x00 -Отладка
        /// </summary>
        [Description("Отладка")]
        DebugVersion = 0x00,

        /// <summary>
        /// 0x01 -Релиз
        /// </summary>
        [Description("Релиз")]
        ReleaseVersion = 0x01
    }

    /// <summary>
    /// Перечисление для статуса информационного обмена с ОФД, битовые флаги
    /// </summary>
    [Flags]
    public enum ConnectionState
    {
        /// <summary>
        /// 0x00 -Нет соединения
        /// </summary>
        [Description("Нет соединения")]
        NoConnection = 0x00,

        /// <summary>
        /// 0x01 -Транспортное соединение установлено
        /// </summary>
        [Description("Транспортное соединение установлено")]
        ConnectionEstablished = 0x01,

        /// <summary>
        /// 0x02 -Есть сообщение для передачи ОФД
        /// </summary>
        [Description("Есть сообщение для передачи ОФД")]
        MessageToOFDQueued = 0x02,

        /// <summary>
        /// 0x04 -Ожидание ответного сообщения (квитанции) от ОФД
        /// </summary>
        [Description("Ожидание ответного сообщения (квитанции) от ОФД")]
        WaitingOFDReceipt = 0x04,

        /// <summary>
        /// 0x08 -Есть команда от ОФД
        /// </summary>
        [Description("Есть команда от ОФД")]
        OFDCommandQueued = 0x08,

        /// <summary>
        /// 0x10 -Изменились настройки соединения с ОФД
        /// </summary>
        [Description("Изменились настройки соединения с ОФД")]
        OFDConnectionChanged = 0x10,

        /// <summary>
        /// 0x20 -Ожидание ответа на команду от ОФД
        /// </summary>
        [Description("Ожидание ответа на команду от ОФД")]
        WaitingForOFDResponse = 0x20
    }

    /// <summary>
    /// Состояние смены
    /// </summary>
    public enum DayState
    {
        /// <summary>
        /// 0x00 -Смена закрыта
        /// </summary>
        [Description("Смена закрыта")]
        DayClosed = 0x00,

        /// <summary>
        /// 0x01 -Смена открыта
        /// </summary>
        [Description("Смена открыта")]
        DayOpen = 0x01
    }

    /// <summary>
    /// Код системы налогообложения
    /// Используется при регистрации и перерегистрации
    /// </summary>
    [Flags]
    public enum TaxCode
    {
        /// <summary>
        /// 0x00 - Не установлено
        /// </summary>
        [Description("Не установлено")]
        None = 0x00,

        /// <summary>
        /// 0x01 -Общая
        /// </summary>
        [Description("ОСН")]
        Common = 0x01,

        /// <summary>
        /// 0x02 -Упрощённая Доход
        /// </summary>
        [Description("УСН доход")]
        Simplified = 0x02,

        /// <summary>
        /// 0x04 -Упрощённая Доход минус Расход
        /// </summary>
        [Description("УСН доход - расход")]
        SimplifiedWithExpense = 0x04,

        /// <summary>
        /// 0x08 -Единый налог на вмененный доход
        /// </summary>
        [Description("ЕНВД")]
        ENVD = 0x08,

        /// <summary>
        /// 0x10 -Единый сельскохозяйственный налог
        /// </summary>
        [Description("ЕСХН")]
        CommonAgricultural = 0x10,

        /// <summary>
        /// 0x20 -Патентная система налогообложения
        /// </summary>
        [Description("Патент")]
        Patent = 0x20
    }

    /// <summary>
    /// Код налога
    /// Используется при оплате и в чеке коррекции.
    /// </summary>
    public enum TaxNum
    {
        /// <summary>
        /// 0 -НДС 20%
        /// </summary>
        [Description("НДС 20%")]
        _20 = 0,

        /// <summary>
        /// 1 -НДС 10%
        /// </summary>
        [Description("НДС 10%")]
        _10 = 1,

        /// <summary>
        /// 2 -НДС 20/120
        /// </summary>
        [Description("НДС 20/120")]
        _20_120 = 2,

        /// <summary>
        /// 3 -НДС 10/110
        /// </summary>
        [Description("НДС 10/110")]
        _10_110 = 3,

        /// <summary>
        /// 4 -НДС 0%
        /// </summary>
        [Description("НДС 0%")]
        _0 = 4,

        /// <summary>
        /// 5 -БЕЗ НДС
        /// </summary>
        [Description("БЕЗ НДС")]
        _NO = 5,

        /// <summary>
        /// 6 -НДС 18%. Для возвратов после 01.01.2019
        /// </summary>
        [Description("НДС 18%")]
        _REFUND_18 = 6,

        /// <summary>
        /// 7 -НДС 18/118. Для возвратов после 01.01.2019
        /// </summary>
        [Description("НДС 18/118%")]
        _REFUND_18_118 = 7
    }

    /// <summary>
    /// Код налога (республика Киргизия)
    /// </summary>
    public enum TaxNumKg
    {
        /// <summary>
        /// 0 - НДС 20%
        /// </summary>
        [Description("НДС 20%")]
        VAT20 = 0,
        /// <summary>
        /// 1 - НДС 12%
        /// </summary>
        [Description("НДС 12%")]
        VAT12 = 1,
        /// <summary>
        /// 2 - НДС 0%
        /// </summary>
        [Description("НДС 0%")]
        VAT0 = 2,
        /// <summary>
        /// 3 - НСП 3%
        /// </summary>
        [Description("НСП 3%")]
        SALES3 = 3,
        /// <summary>
        /// 4 - НСП 2%
        /// </summary>
        [Description("НСП 2%")]
        SALES2 = 4,
        /// <summary>
        /// 5 - НСП 1%
        /// </summary>
        [Description("НСП 1%")]
        SALES1 = 5,
        /// <summary>
        /// 6 - НСП 0%
        /// </summary>
        [Description("НСП 0%")]
        SALES0 = 6
    }

    /// <summary>
    /// Режимы работы ФН
    /// </summary>
    [Flags]
    public enum OperatingMode
    {
        /// <summary>
        /// 0x00 -Основной режим работы
        /// </summary>
        [Description("0 Основной")]
        Default = 0x00,

        /// <summary>
        /// 0x01 -Шифрование
        /// </summary>
        [Description("1  Шифрование")]
        Encryption = 0x01,

        /// <summary>
        /// 0x02 -Автономный режим
        /// </summary>
        [Description("2  Автономный режим")]
        Autonomous = 0x02,

        /// <summary>
        /// 0x04 -Автоматический режим
        /// </summary>
        [Description("4  Автоматический режим")]
        Automatic = 0x04,

        /// <summary>
        /// 0x08 -Применение в сфере услуг
        /// </summary>
        [Description("8  Применение в сфере услуг")]
        Service = 0x08,

        /// <summary>
        /// 0x10 -Режим БСО (иначе - режим чеков)
        /// </summary>
        [Description("16 Режим БСО (иначе – режим чеков)")]
        BSOMode = 0x10,

        /// <summary>
        /// 0x20 -Применение в Интернет
        /// </summary>
        [Description("32 Применение в Интернет")]
        InternetUsing = 0x20
    }

    /// <summary>
    /// Тип открытого чека
    /// </summary>
    public enum RecType
    {
        /// <summary>
        /// 1 -Приход
        /// </summary>
        [Description("ПРИХОД")]
        Sell = 1,

        /// <summary>
        /// 3 -Bозврат прихода
        /// </summary>
        [Description("ВОЗВРАТ ПРИХОДА")]
        SellRefund = 3,

        /// <summary>
        /// 2 -Расход
        /// </summary>
        [Description("РАСХОД")]
        Buy = 2,

        /// <summary>
        /// 4 -Возврат расхода
        /// </summary>
        [Description("ВОЗВРАТ РАСХОДА")]
        BuyRefund = 4,

        /// <summary>
        /// 19 -Чек коррекции
        /// </summary>
        [Description("Чек коррекции")]
        CorrectionRec = 19,

        /// <summary>
        /// 7 -Внесение
        /// </summary>
        [Description("Внесение")]
        PayIn = 7,

        /// <summary>
        /// 8 -Изъятие
        /// </summary>
        [Description("Изъятие")]
        PayOut = 8,

        /// <summary>
        /// 9 -Нефискальный
        /// </summary>
        [Description("Нефискальный")]
        Unfiscal = 9,

        /// <summary>
        /// 21 - Коррекция прихода (ФФД 1.1)
        /// </summary>
        [Description("Коррекция прихода")]
        SellCorrection = 21,
        /// <summary>
        /// 22 - Коррекция расхода (ФФД 1.1)
        /// </summary>
        [Description("Коррекция расхода")]
        BuyCorrection = 22,
        /// <summary>
        /// 23 - Коррекция возврата прихода (ФФД 1.1)
        /// </summary>
        [Description("Коррекция возврата прихода")]
        SellRefundCorrection = 23,
        /// <summary>
        /// 24 - Коррекция возврата расхода (ФФД 1.1)
        /// </summary>
        [Description("Коррекция возврата расхода")]
        BuyRefundCorrection = 24
    }


    /// <summary>
    /// Тип операции
    /// </summary>
    public enum OperationType : byte
    {
        /// <summary>
        /// 1 -Приход
        /// </summary>
        [Description("ПРИХОД")]
        Sell = 0x01,
        /// <summary>
        /// 2 -Возврат прихода
        /// </summary>
        [Description("ВОЗВРАТ ПРИХОДА")]
        SellRefund = 0x02,
        /// <summary>
        /// 3 -Расход
        /// </summary>
        [Description("РАСХОД")]
        Buy = 0x03,
        /// <summary>
        /// 4 -Возврат расхода
        /// </summary>
        [Description("ВОЗВРАТ РАСХОДА")]
        BuyRefund = 0x04
    }

    /// <summary>
    /// Тип коррекции. Применяется в чеке коррекции
    /// </summary>
    public enum CorrectionRecType
    {
        /// <summary>
        /// 0 -Самостоятельная
        /// </summary>
        [Description("Самостоятельная")]
        Independent = 0,

        /// <summary>
        /// 1 -По предписанию
        /// </summary>
        [Description("По предписанию")]
        ByOrder = 1
    }

    /// <summary>
    /// Признак агента
    /// </summary>
    [Flags]
    public enum AgentTag
    {
        /// <summary>
        /// 0 -Агентом не является
        /// </summary>
        None = 0,

        /// <summary>
        /// 1 -Банковский платёжный агент
        /// </summary>
        BankPayAgent = 1,

        /// <summary>
        /// 2 -Банковский платёжный субагент
        /// </summary>
        BankPaySubAgent = 2,

        /// <summary>
        /// 4 -Платёжный агент
        /// </summary>
        PayAgent = 4,

        /// <summary>
        /// 8 -Платёжный субагент
        /// </summary>
        PaySubAgent = 8,

        /// <summary>
        /// 16 -Поверенный
        /// </summary>
        Attorney = 16,

        /// <summary>
        /// 32 -Комиссионер
        /// </summary>
        CommissionAgent = 32,

        /// <summary>
        /// 64 -Иной агент
        /// </summary>
        Agent = 64
    }

    /// <summary>
    /// Причина коррекции. Применяется при перерегистрации
    /// </summary>
    public enum CorrectionReason
    {
        /// <summary>
        /// 0 -Регистрация
        /// </summary>
        [Description("0 - регистрация")]
        Register = 0,

        /// <summary>
        /// 1 -Замена ФН
        /// </summary>
        [Description("1 - замена ФН")]
        ChangeFN = 1,

        /// <summary>
        /// 2 -Смена ОФД
        /// </summary>
        [Description("2 - смена ОФД")]
        ChangeOFD = 2,

        /// <summary>
        /// 3 -Смена реквизитов
        /// </summary>
        [Description("3 - смена реквизитов пользователя")]
        ChangeUserAttr = 3,

        /// <summary>
        /// 4 -Смена настроек ККТ
        /// </summary>
        [Description("4 - смена настроек ккт")]
        ChangeKKTSettings = 4
    }

    /// <summary>
    /// Флаги отрезки (если есть отрезчик)
    /// </summary>
    public enum CutType
    {
        /// <summary>
        /// 0 -Отключена
        /// </summary>
        Off = 0,

        /// <summary>
        /// 1 -Полная
        /// </summary>
        Full = 1,

        /// <summary>
        /// 2 -Частичная
        /// </summary>
        Partial = 2
    }

    /// <summary>
    /// Состояние чека
    /// </summary>
    public enum RecState
    {
        /// <summary>
        /// 0 -Открыт
        /// </summary>
        Opened = 0,

        /// <summary>
        /// 1 -Оплата
        /// </summary>
        Total = 1,

        /// <summary>
        /// 2 -Закрыт
        /// </summary>
        Closed = 2
    }

    /// <summary>
    /// Выравнивание
    /// </summary>
    public enum Align
    {
        /// <summary>
        /// 0 -Выравнивание влево
        /// </summary>
        Left = 0,

        /// <summary>
        /// 1 -Выравнивание по центру
        /// </summary>
        Center = 1,

        /// <summary>
        /// 2 -Выравнивание вправо
        /// </summary>
        Right = 2
    }


    /// <summary>
    /// Счётчики
    /// </summary>
    public enum Counter
    {
        /// <summary>
        /// 0 -Аннулирования
        /// </summary>
        [Description("Аннулирования")]
        VOID = 0,
        /// <summary>
        /// 1 -Приход
        /// </summary>
        [Description("Приход")]
        SELL = 1,
        /// <summary>
        /// 2 -Возврат прихода
        /// </summary>
        [Description("Возврат прихода")]
        SELL_REFUND = 2,
        /// <summary>
        /// 3 -Расход
        /// </summary>
        [Description("Расход")]
        BUY = 3,
        /// <summary>
        /// 4 -Возврат расхода
        /// </summary>
        [Description("Возврат расхода")]
        BUY_REFUND = 4,
        /// <summary>
        /// 5 -Наличные
        /// </summary>
        [Description("Наличные")]
        CASH = 5,
        /// <summary>
        /// 6 -Электронные
        /// </summary>
        [Description("Электронные")]
        CARD = 6,
        /// <summary>
        /// 7 -Кредит
        /// </summary>
        [Description("Последующая оплата(Кредит)")]
        BANK = 7,
        /// <summary>
        /// 8 -Иная форма оплаты
        /// </summary>
        [Description("Иная форма оплаты")]
        TARE = 8,
        /// <summary>
        /// 9 -Аванс
        /// </summary>
        [Description("Предварительная оплата(Аванс)")]
        VOUCHER = 9,
        /// <summary>
        /// 10 -Внесение
        /// </summary>
        [Description("Внесение")]
        PAID_IN = 10,
        /// <summary>
        /// 11 -Изъятие
        /// </summary>
        [Description("Изъятие")]
        PAID_OUT = 11,
        /// <summary>
        /// 14 -X-отчёт
        /// </summary>
        [Description("X-отчёт")]
        X_REPORT = 14,
        /// <summary>
        /// 15 -Z-отчёт
        /// </summary>
        [Description("Отчёт о закрытии смены")]
        Z_REPORT = 15,
        /// <summary>
        /// 16 -Отмены
        /// </summary>
        [Description("Отмены")]
        CANCEL = 16,
        /// <summary>
        /// 17 -Документы
        /// </summary>
        [Description("Документы")]
        NUMBER = 17,
        /// <summary>
        /// 18 -Коррекции
        /// </summary>
        [Description("Коррекции")]
        CORRECTION = 18
    }

    public enum BarCode
    {
        /// <summary>
        /// 0 -UPC-A
        /// </summary>
        UpcA = 0,
        /// <summary>
        /// 1 -UPC-E
        /// </summary>
        UpcE = 1,
        /// <summary>
        /// 2 -JAN13(EAN13)
        /// </summary>
        Ean13 = 2,
        /// <summary>
        /// 3 -JAN8(EAN8)
        /// </summary>
        Ean8 = 3,
        /// <summary>
        /// 4 -CODE39
        /// </summary>
        Code39 = 4,
        /// <summary>
        /// 5 -ITF
        /// </summary>
        Itf = 5,
        /// <summary>
        /// 6 -CODABAR
        /// </summary>
        Codabar = 6,
        /// <summary>
        /// 7 -CODE93
        /// </summary>
        Code93 = 7,
        /// <summary>
        /// 10 -CODE128
        /// </summary>
        Code128 = 10
    }

    /// <summary>
    /// Тег. Аргумент функции IFiscalCore.SetTagAttribute
    /// </summary>
    public enum Tag
    {
        /// <summary>
        /// <para>1207 - Признак торговли подакцизными товарами.</para>
        /// <para>Значения: 0 или 1</para>
        /// <para>По умолчанию 0 - не указан</para>
        /// </summary>
        [Description("Признак торговли подакцизными товарами")]
        ExciseTag = 1207,
        /// <summary>
        /// <para>1212 -Признак предмета расчёта.</para>
        /// <para>Значения: от 1 до 26 включительно.</para>
        /// <para>По умолчанию 0 - не указан.</para>
        /// <see cref="http://77.243.109.96:8881/redmine/projects/mspos-k/wiki/QA#Q19"/>
        /// </summary>
        [Description("Признак предмета расчёта")]
        ItemProperty = 1212,
        /// <summary>
        /// <para>1214 -Признак способа расчёта.</para>
        /// <para>Значения: от 1 до 7 включительно.</para>
        /// <para>По умолчанию 0 - не указан.</para>
        /// <see cref="http://77.243.109.96:8881/redmine/projects/mspos-k/wiki/QA#Q19"/>
        /// </summary>
        [Description("Признак способа расчёта")]
        PaymentProperty = 1214,
        /// <summary>
        /// <para>1162 - Код товара (КТН).</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Код товара")]
        CommodityCode = 1162,
        /// <summary>
        /// <para>1226 - ИНН поставщика  в предмете расчёта.</para>
        /// <para>Не более 12 символов.</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("ИНН поставщика")]
        SupplierTaxId = 1226,
        /// <summary>
        /// <para>1171 - Телефон поставщика  в предмете расчёта.</para>
        /// <para>Максимум 19 символов.</para>
        /// <para>Формат: "+{Ц}" без кавычек, где {Ц} - последоательность цифр.</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// <para>Входит в STLV 1224 (Данные поставщика).</para>
        /// </summary>
        [Description("Телефон поставщика")]
        SupplierTelNum = 1171,
        /// <summary>
        /// <para>1225 - Наименование поставщика в предмете расчёта.</para>
        /// <para>Максимум 256 символов.</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// <para>Входит в STLV 1224 (Данные поставщика).</para>
        /// </summary>
        [Description("Наименование поставщика")]
        SupplierName = 1225,
        /// <summary>
        /// <para>1222 - Признак агента по предмету расчёта.</para>
        /// <para>По умолчанию 0 - не указан.</para>
        /// <seealso cref="AgentTag"/>
        /// </summary>
        [Description("Признак агента по предмету расчёта")]
        AgentTagByCommodity = 1222,
        /// <summary>
        /// <para>1230 - Код страны происхождения товара.</para>
        /// <para>Значение - до 3 цифр включительно. Если меньше 3, ФЯ дополняет его пробелами справа.</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Код страны происхождения товара")]
        OriginCode = 1230,
        /// <summary>
        /// <para>1231 - Номер таможенной декларации.</para>
        /// <para>Не более 32 символов.</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Номер таможенной декларации")]
        CustomsDeclNum = 1231,
        /// <summary>
        /// <para>1073 - Телефон платёжного агента в предмете расчёта.</para>
        /// <para>Максимум 19 символов.</para>
        /// <para>Формат: "+{Ц}" без кавычек, где {Ц} - последоательность цифр.</para>
        /// <para>ФВходит в STLV 1223 (Данные агента).</para>
        /// <para>ФПо умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Телефон платёжного агента")]
        PaymentAgentTelNum = 1073,
        /// <summary>
        /// <para>1074 - Телефон оператора по приёму платежей в предмете расчёта.</para>
        /// <para>Максимум 19 символов.</para>
        /// <para>Формат: "+{Ц}" без кавычек, где {Ц} - последоательность цифр.</para>
        /// <para>Входит в STLV 1223 (Данные агента).</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Телефон оператора по приёму платежей")]
        ProcessingOperatorTelNum = 1074,
        /// <summary>
        /// <para>1075 - Телефон оператора перевода в предмете расчёта.</para>
        /// <para>Максимум 19 символов.</para>
        /// <para>Формат: "+{Ц}" без кавычек, где {Ц} - последоательность цифр.</para>
        /// <para>Входит в STLV 1223 (Данные агента).</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Телефон оператора перевода")]
        TransferOperatorTelNum = 1075,
        /// <summary>
        /// <para>1044 - Операция платёжного агента в предмете расчёта.</para>
        /// <para>Максимум 24 символа.</para>
        /// <para>Входит в STLV 1223 (Данные агента).</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Операция платёжного агента")]
        PaymentAgentOperation = 1044,
        /// <summary>
        /// <para>1005 - Адрес оператора перевода в предмете расчёта.</para>
        /// <para>Максимум 256 символов.</para>
        /// <para>Входит в STLV 1223 (Данные агента).</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Адрес оператора перевода")]
        TransferOperatorAddress = 1005,
        /// <summary>
        /// <para>1016 - ИНН оператора перевода в предмете расчёта.</para>
        /// <para>Значение - 12 цифр. Если меньше 12, ФЯ дополняет его пробелами справа.</para>
        /// <para>Входит в STLV 1223 (Данные агента).</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("ИНН оператора перевода")]
        TransferOperatorTaxId = 1016,
        /// <summary>
        /// <para>1026 - Наименование оператора перевода в предмете расчёта.</para>
        /// <para>Максимум 64 символа.</para>
        /// <para>Входит в STLV 1223 (Данные агента).</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Наименование оператора перевода")]
        TransferOperatorName = 1026,
        /// <summary>
        /// <para>1227 - Покупатель</para>
        /// <para>Может быть указан не более 1 раза на чек</para>
        /// <para>Максимум 256 символов.</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Покупатель")]
        Buyer = 1227,
        /// <summary>
        /// <para>1228 - ИНН покупателя</para>
        /// <para>Может быть указан не более 1 раза на чек</para>
        /// <para>Максимум 12 символов.</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("ИНН покупателя")]
        BuyerTaxId = 1228,
        /// <summary>
        /// <para>1009 - Адрес расчётов</para>
        /// <para>Может быть указан не более 1 раза на чек</para>
        /// <para>Переопределяет указанный при регистрации адрес расчётов (IFiscalCore.SetOrgAddress).</para>
        /// </summary>
        [Description("Адрес расчётов")]
        OrgAddress = 1009,
        /// <summary>
        /// <para>1187 - Место расчётов</para>
        /// <para>Может быть указан не более 1 раза на чек</para>
        /// <para>Переопределяет указанное при регистрации место расчётов (IFiscalCore.SetPhysicalAddress).</para>
        /// </summary>
        [Description("Место расчётов")]
        PhysicalAddress = 1187,
        /// <summary>
        /// <para>1200 - Сумма НДС за предмет расчёта</para>
        /// <para>Сумма в рублях и копейках.</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Сумма НДС за предмет расчёта")]
        VatForCommodity = 1200,
        /// <summary>
        /// <para>1191 - Дополнительный реквизит предмета расчета</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Дополнительный реквизит предмета расчета")]
        CommodityAdditionalProp = 1191,
        /// <summary>
        /// <para>1192 - Дополнительный реквизит чека (БСО)</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Дополнительный реквизит чека (БСО)")]
        ReceiptAdditionalProp = 1192,
        /// <summary>
        /// <para>1085 - наименование дополнительного реквизита пользователя</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Наименование дополнительного реквизита пользователя")]
        AdditionalPropName = 1085,
        /// <summary>
        /// <para>1086 - Значение дополнительного реквизита пользователя</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Значение дополнительного реквизита пользователя")]
        AdditionalPropValue = 1086,
        /// <summary>
        /// <para>1229 - Акциз</para>
        /// <para>Сумма в рублях и копейках.</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Акциз")]
        Excise = 1229,
        /// <summary>
        /// <para>1197 - единица измерения предмета расчета</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Единица измерения предмета расчета")]
        ItemUnit = 1197,
        /// <summary>
        /// <para>1270 - операционный реквизит чека</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Операционный реквизит чека")]
        ReceiptOperationalProperty = 1270,
        /// <summary>
        /// <para>1271 - идентификатор операции</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Идентификатор операции")]
        OperationId = 1271,
        /// <summary>
        /// <para>1272 - данные операции</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Данные операции")]
        OperationData = 1272,
        /// <summary>
        /// <para>1273 - дата, время операции</para>
        /// <para>По умолчанию - пустая строка - не указан.</para>
        /// </summary>
        [Description("Дата, время операции")]
        OperationDateTime = 1273,
        /// <summary>
        /// <para>1261 - отраслевой реквизит чека</para>
        /// </summary>
        [Description("Отраслевой реквизит чека")]
        BranchReceiptProperty = 1261,
        /// <summary>
        ///1262 - идентификатор ФОИВ (федеральный орган исполнительной власти)
        /// </summary>
        [Description("Идентификатор ФОИВ (федеральный орган исполнительной власти)")]
        GovExecutiveId = 1262,
        /// <summary>
        ///1263 - дата документа основания
        /// </summary>
        [Description("Дата документа основания")]
        BasisDocDate = 1263,
        /// <summary>
        ///1264 - номер документа основания
        /// </summary>
        [Description("Номер документа основания")]
        BasisDocNum = 1264,
        /// <summary>
        ///1265 - значение отраслевого реквизита
        /// </summary>
        [Description("Значение отраслевого реквизита")]
        BranchPropertyValue = 1265,
        /// <summary>
        ///1163 - Новый тег кода товара, который стал структурой
        /// </summary>
        [Description("Новый тег кода товара, который стал структурой")]
        MarkedCommodityCode = 1163,
        /// <summary>
        ///2108 - мера количества предмета расчета
        /// </summary>
        [Description("Мера количества предмета расчета")]
        MeasurementUnit = 2108,

        /// <summary>
        ///1276 - дополнительный реквизит ООС (отчет открытия смены)
        /// </summary>
        [Description("Дополнительный реквизит ООС (отчет открытия смены)")]
        DayOpenReportAdditionalItem = 1276,

        /// <summary>
        ///1277 - дополнительные данные ООС (отчет открытия смены)
        /// </summary>
        [Description("Дополнительные данные ООС (отчет открытия смены)")]
        DayOpenReportAdditionalData = 1277,

        /// <summary>
        ///1243 - дата рождения покупателя (клиента)
        /// </summary>
        [Description("Дата рождения покупателя (клиента)")]
        CustomerBirthDate = 1243,

        /// <summary>
        ///1244 - гражданство
        /// </summary>
        [Description("Гражданство")]
        CustomerNationality = 1244,

        /// <summary>
        ///1245 - код вида документа, удостоверяющего личность
        /// </summary>
        [Description("Код вида документа, удостоверяющего личность")]
        IdentityDocCode = 1245,

        /// <summary>
        ///1246 - данные документа, удостоверяющего личность
        /// </summary>
        [Description("Данные документа, удостоверяющего личность")]
        IdentityDocData = 1246,

        /// <summary>
        ///1254 - адрес покупателя (клиента)
        /// </summary>
        [Description("Адрес покупателя (клиента)")]
        CustomerAddress = 1254,

        /// <summary>
        ///1274 - дополнительный реквизит ОР (Отчета регистрации)
        /// </summary>
        [Description("Дополнительный реквизит ОР (Отчета регистрации)")]
        RegistrationReportAdditionalItem = 1274,

        /// <summary>
        ///1275 - дополнительные данные ОР (Отчета регистрации)
        /// </summary>
        [Description("Дополнительные данные ОР (Отчета регистрации)")]
        RegistrationReportAdditionalData = 1275,

        /// <summary>
        ///1278 - дополнительный реквизит ОЗС (отчет закрытия смены)
        /// </summary>
        [Description("Дополнительный реквизит ОЗС (отчет закрытия смены)")]
        DayCloseReportAdditionalItem = 1278,

        /// <summary>
        ///1279 - дополнительные данные ОЗС (отчет закрытия смены)
        /// </summary>
        [Description("Дополнительные данные ОЗС (отчет закрытия смены)")]
        DayCloseReportAdditionalData = 1279,

        /// <summary>
        ///1282 - дополнительный реквизит ОЗФН (отчет закрытия фискального накопителя)
        /// </summary>
        [Description("Дополнительный реквизит ОЗФН (отчет закрытия фискального накопителя)")]
        FnCloseReportAdditionalItem = 1282,

        /// <summary>
        ///1283 - дополнительные данные ОЗФН (отчет закрытия фискального накопителя)
        /// </summary>
        [Description("Дополнительные данные ОЗФН (отчет закрытия фискального накопителя)")]
        FnCloseReportAdditionalData = 1283,

        /// <summary>
        ///1280 - дополнительный реквизит ОТР (отчет текущего состояния расчетов)
        /// </summary>
        [Description("Дополнительный реквизит ОТР (отчет текущего состояния расчетов)")]
        PaymentStatusDocAdditionalItem = 1280,

        /// <summary>
        ///1281 - дополнительные данные ОТР (отчет текущего состояния расчетов)
        /// </summary>
        [Description("Дополнительные данные ОТР (отчет текущего состояния расчетов)")]
        PaymentStatusDocAdditionalData = 1281,

        /// <summary>
        ///1260 - отраслевой реквизит предмета расчета
        /// </summary>
        [Description("Отраслевой реквизит предмета расчета")]
        BranchItemProperty = 1260,


    }

    /// <summary>
    /// Печатная форма тега
    /// </summary>
    public enum TagPrintForm
    {
        /// <summary>
        /// Печать выключена (если возможно)
        /// </summary>
        Off = 0,
        /// <summary>
        /// Сокращённая форма (если есть)
        /// </summary>
        Short = 1,
        /// <summary>
        /// Полная форма (по умолчанию)
        /// </summary>
        Full = 2
    }

    /// <summary>
    /// Режим работы ККТ. Аргумент <see href="http://doc.multisoft.ru/doc/MSPOS/IAuth.aidl">IAuth.Result</see>
    /// </summary>
    public enum Mode
    {
        /// <summary>
        /// 0 -ОФД
        /// </summary>
        [Description("ОФД")]
        OFD = 0,
        /// <summary>
        /// 1 -ЧПМ (ЕНВД без ФН)
        /// </summary>
        [Description("ЧПМ (ЕНВД без ФН)")]
        ENVD = 1
    }

    /// <summary>
    /// Код команды DirectIO.
    /// Для ChangeMode и GetMode в результате успешного выполнения IFisalCore.DirectIO 
    /// в аргументе <see href="http://doc.multisoft.ru/doc/MSPOS/IAuth.aidl">IAuth.Result</see> 
    /// передаётся код нового режима работы (Mode.OFD или Mode.ENVD)
    /// </summary>
    public enum DirectIOCmd
    {
        /// <summary>
        /// -2 -смена режима работы ККТ (ОФД/ЧПМ). 
        /// </summary>
        ChangeMode = -2,
        /// <summary>
        /// -1 -запрос режима работы ККТ (ОФД/ЧПМ)
        /// </summary>
        GetMode = -1,
    }

    /// <summary>
    /// Команды управления логгером
    /// </summary>
    public enum LoggerCommand
    {
        /// <summary>
        /// 0 -ротировать лог
        /// </summary>
        Rotate = 0,
        /// <summary>
        /// 2 -выгрузить логи на карту памяти
        /// </summary>
        UploadToSD = 2
    }

    /// <summary>
    /// Коды причин изменения сведений о ККТ (TLV 1205, ФН 1.1)
    /// </summary>
    [Flags]
    public enum RegParamsChangeCode : uint
    {
        /// <summary>
        /// 0x01 - Замена фискального накопителя
        /// </summary>
        FnReplaced = 0x01,
        /// <summary>
        /// 0x02 - Замена оператора фискальных данных
        /// </summary>
        OfdChanged = 0x02,
        /// <summary>
        /// 0x04 - Изменение наименования пользователя контрольно-кассовой техники
        /// </summary>
        UsernameChanged = 0x04,
        /// <summary>
        /// 0x08 - Изменение адреса и (или) места установки (применения) контрольно-кассовой техники
        /// </summary>
        AddressChanged = 0x08,
        /// <summary>
        /// 0x10 - Перевод ККТ из автономного режима в режим передачи данных
        /// </summary>
        OfflineToOnline = 0x10,
        /// <summary>
        /// 0x20 - Перевод ККТ из режима передачи данных в автономный режим
        /// </summary>
        OnlineToOffline = 0x20,
        /// <summary>
        /// 0x40 - Изменение версии модели ККТ
        /// </summary>
        EcrModelChanged = 0x40,
        /// <summary>
        /// 0x80 - Изменение перечня систем налогообложения, применяемых при осуществлении расчетов
        /// </summary>
        TaxationChanged = 0x80,
        /// <summary>
        /// 0x100 - Изменение номера автоматического устройства для расчетов, в составе которого применяется ККТ
        /// </summary>
        VendingSerialChanged = 0x100,
        /// <summary>
        /// 0x200 - Перевод ККТ из автоматического режима в неавтоматический режим (осуществление расчетов кассиром)
        /// </summary>
        AutoToManual = 0x200,
        /// <summary>
        /// 0x400 - Перевод ККТ из неавтоматического режима (осуществление расчетов кассиром) в автоматический режим
        /// </summary>
        ManualToAuto = 0x400,
        /// <summary>
        /// 0x800 - Перевод ККТ из режима, не позволяющего формировать БСО, в режим, позволяющий формировать БСО
        /// </summary>
        ReceiptToBSO = 0x800,
        /// <summary>
        /// 0x1000 - Перевод ККТ из режима, позволяющего формировать БСО, в режим, не позволяющий формировать БСО
        /// </summary>
        BSOToReceipt = 0x1000,
        /// <summary>
        /// 0x2000 - Перевод ККТ из режима расчетов в сети Интернет (позволяющего не печатать кассовый чек и БСО) в режим, позволяющий печатать кассовый чек и БСО
        /// </summary>
        InternetToRegular = 0x2000,
        /// <summary>
        /// 0x4000 - Перевод ККТ из режима, позволяющего печатать кассовый чек и БСО, в режим расчетов в сети Интернет (позволяющего не печатать кассовый чек и БСО)
        /// </summary>
        RegularToInternet = 0x4000,
        /// <summary>
        /// 0x8000 - Перевод ККТ из режима, позволяющего оказывать услуги платежного агента (субагента) или банковского платежного агента, в режим, не позволяющий оказывать услуги платежного агента (субагента) или банковского платежного агента
        /// </summary>
        AgentToRegular = 0x8000,
        /// <summary>
        /// 0x10000 - Перевод ККТ из режима, не позволяющего оказывать услуги платежного агента (субагента) или банковского платежного агента в режим, позволяющий оказывать услуги платежного агента (субагента) или банковского платежного агента
        /// </summary>
        RegularToAgent = 0x10000,
        /// <summary>
        /// 0x20000 - Перевод ККТ из режима, позволяющего применять ККТ при приеме ставок и выплате денежных средств в виде выигрыша при осуществлении деятельности по проведению азартных игр, в режим, не позволяющий применять ККТ при приеме ставок и выплате денежных средств в виде выигрыша при осуществлении деятельности по проведению азартных игр
        /// </summary>
        GamblingToRegular = 0x20000,
        /// <summary>
        /// 0x40000 - Перевод ККТ из режима, не позволяющего применять ККТ при приеме ставок и выплате денежных средств в виде выигрыша при осуществлении деятельности по проведению азартных игр, в режим, позволяющий применять ККТ при приеме ставок и выплате денежных средств в виде выигрыша при осуществлении деятельности по проведению азартных игр
        /// </summary>
        RegularToGambling = 0x40000,
        /// <summary>
        /// 0x80000 - Перевод ККТ из режима, позволяющего применять ККТ при приеме денежных средств при реализации лотерейных билетов, электронных лотерейных билетов, приеме лотерейных ставок и выплате денежных средств в виде выигрыша при осуществлении деятельности по проведению лотерей, в режим, не позволяющий применять ККТ при приеме денежных средств при реализации лотерейных билетов, электронных лотерейных билетов, приеме лотерейных ставок и выплате денежных средств в виде выигрыша при осуществлении деятельности по проведению лотерей
        /// </summary>
        LotteryToRegular = 0x80000,
        /// <summary>
        /// 0x100000 - Перевод ККТ из режима, не позволяющего применять ККТ при приеме денежных средств при реализации лотерейных билетов, электронных лотерейных билетов, приеме лотерейных ставок и выплате денежных средств в виде выигрыша при осуществлении деятельности по проведению лотерей, в режим, позволяющий применять ККТ при приеме денежных средств при реализации лотерейных билетов, электронных лотерейных билетов, приеме лотерейных ставок и выплате денежных средств в виде выигрыша при осуществлении деятельности по проведению лотерей
        /// </summary>
        RegularToLottery = 0x100000,
        /// <summary>
        /// 0x200000 - Изменение версии ФФД
        /// </summary>
        FfdVersionChanged = 0x200000,
        /// <summary>
        /// 0x80000000 - Иные причины
        /// </summary>
        OtherReason = 0x80000000,
    }

    /// <summary>
    /// Режим формирования печатной формы чека
    /// </summary>
    public enum ReceiptRenderMode
    {
        /// <summary>
        /// 0 - обычный режим. Построчная печать.
        /// </summary>
        Normal = 0,
        /// <summary>
        /// 1 - компактный режим. Печать QR, огибающего текст.
        /// </summary>
        Compact = 1
    }

    /// <summary>
    /// Версия форматов фискальных данных
    /// </summary>
    public enum FfdVersion : byte
    {
        /// <summary>
        /// 1 - ФФД версии 1.0
        /// </summary>
        FFD_1_0 = 0x01,
        /// <summary>
        /// 2 - ФФД версии 1.05
        /// </summary>
        FFD_1_05 = 0x02,
        /// <summary>
        /// 3 - ФФД версии 1.1
        /// </summary>
        FFD_1_1 = 0x03,
        /// <summary>
        /// 4 - ФФД версии 1.2
        /// </summary>
        FFD_1_2 = 0x04
    }
}